@@ -270,7 +270,7 @@ class CoordinatesDisplacement(object):
         to_xyz = to_positions.xyz()
         dxyz = XYZ(to_xyz.x - from_xyz.x, to_xyz.y - from_xyz.y, to_xyz.z - from_xyz.z)
 
-        return CoordinatesDisplacement(xyz=dxyz)
+        return CoordinatesDisplacement(xyz=dxyz, ref_position=from_position)
 
     @staticmethod
     def from_enu(e: float, n: float, u: float):
